import { Utils } from "./utils";
export let CssUtils;
(function (_CssUtils) {
  function filterAutomaticThemes() {
    let defaultThemes = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    let customThemes = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    if (!Utils.isEmpty(customThemes)) {
      //look for automatic themes in custom ones
      const automaticCustomThemes = Object.keys(customThemes).filter(theme => customThemes[theme].automatic === 1);
      if (!Utils.isEmpty(automaticCustomThemes)) {
        //check for custom automatic light theme
        const automaticLightTheme = automaticCustomThemes.filter(theme => customThemes[theme].dark === 0);
        //check for custom automatic dark theme
        const automaticDarkTheme = automaticCustomThemes.filter(theme => customThemes[theme].dark === 1);
        if (!Utils.isEmpty(automaticLightTheme)) {
          //discard default automatic light styles
          Object.keys(defaultThemes).filter(theme => defaultThemes[theme].automatic === 1 && defaultThemes[theme].dark === 0).forEach(theme => delete defaultThemes[theme]);
        }
        if (!Utils.isEmpty(automaticDarkTheme)) {
          //discard default automatic dark styles
          Object.keys(defaultThemes).filter(theme => defaultThemes[theme].automatic === 1 && defaultThemes[theme].dark === 1).forEach(theme => delete defaultThemes[theme]);
        }
      }
      //check defaults
      const defaultCustomTheme = Object.keys(customThemes).filter(theme => customThemes[theme].default === 1);
      if (!Utils.isEmpty(defaultCustomTheme)) {
        //discard default styles
        Object.keys(defaultThemes).filter(theme => defaultThemes[theme].default === 1).forEach(theme => delete defaultThemes[theme]);
      }
    }
  }
  function mergeRnStyles(defaultStyles) {
    for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }
    return args.reduce((result, arg) => {
      filterAutomaticThemes(defaultStyles.themes, arg.themes);
      return Utils.mergeObjects(result, arg);
    }, defaultStyles);
  }
  _CssUtils.mergeRnStyles = mergeRnStyles;
  function resolvePlaceholders() {
    let style = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    let params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    const paramKeys = Object.keys(params);
    if (paramKeys.length === 0) {
      return style;
    }
    return Object.keys(style).reduce((prev, key) => {
      let rule = style[key];
      if (typeof rule !== "string" || !rule.match("{.+}")) {
        prev[key] = rule;
      } else {
        paramKeys.forEach(paramKey => {
          rule = rule.replace(new RegExp(`{${paramKey}}`, "gm"), params[paramKey]);
          try {
            // eslint-disable-next-line no-eval
            prev[key] = eval(rule);
          } catch (e) {}
        });
      }
      return prev;
    }, {});
  }
  _CssUtils.resolvePlaceholders = resolvePlaceholders;
})(CssUtils || (CssUtils = {}));
//# sourceMappingURL=css-utils.js.map