export type IStyle = {
    [key: string]: number | string | IStyle | undefined;
};
export type ISize = {
    width: number;
    height: number;
};
export type IConstraint = "padding" | "margin" | "border";
export type IConstraints = {
    start: number;
    end: number;
    top: number;
    bottom: number;
};
export type IAttributes = {
    cssKey?: string;
    active?: boolean;
    toggle?: boolean;
    ignoreKeys?: string[];
};
export type IMediaQuery = `mw${number}`;
export type ICssField = {
    [key: IMediaQuery | string]: number | string | ICssField | undefined;
};
export type ICss = {
    phone?: ICss & ICssField;
    tablet?: ICss & ICssField;
    portrait?: ICss & ICssField;
    landscape?: ICss & ICssField;
    ios?: ICss & ICssField;
    android?: ICss & ICssField;
    native?: ICss & ICssField;
    web?: ICss & ICssField;
    windows?: ICss & ICssField;
} & ICssField;
export type IRnStyle = {
    [key: string]: ICss;
};
export type IRnTheme = {
    name: string;
    default?: 0 | 1;
    dark?: 0 | 1;
    automatic?: 0 | 1;
    styles?: IRnStyle;
};
export type IRnThemes = {
    [key: "automatic" | string]: IRnTheme;
};
export type IRnStyles = {
    base?: {
        styles: IRnStyle;
    };
    baseLight?: {
        styles: IRnStyle;
    };
    baseDark?: {
        styles: IRnStyle;
    };
    themes?: IRnThemes;
};
export type IDecorators = {
    classes: string[];
} & IAttributes;
export type ICssContext = {
    rnStyles?: IRnStyles;
    activeTheme?: string;
    isDark?: boolean;
    isTablet?: boolean;
    isPortrait?: boolean;
    window?: ISize;
};
export type ICssContextDecorated = {
    [key: string]: any;
};
//# sourceMappingURL=types.d.ts.map